Python Library — LASSO Python Library

# Python Library

This is the free Python Library from LASSO GmbH (https://www.lasso.de/en). The repository contains a fraction of our internal codebase for public use.

# Contact

You like our work? Contact Us:

> Website

> Mail

> LinkedIn

Discussions on:

> Discord

# Installation

    python -m pip install lasso-python

# Modules

- lasso.ansa
  - rest
  - grpc
- lasso.dyna
  - Binout
  - D3plot
  - ArrayType
  - FilterType
  - Performance Info
  - D3plot Example
- lasso.diffcrash
  - DiffcrashRun
  - run

# Indices and tables

- Index

- Privacy Policy